@@ -1,9 +1,11 @@
 """Data classes and enums for representing roles, permissions, and policies."""
 
+from __future__ import annotations
+
 import re
 from abc import abstractmethod
 from enum import Enum
-from typing import ClassVar, Literal, Type
+from typing import Any, ClassVar, Literal, Type
 
 from attrs import define
 from opaque_keys import InvalidKeyError
@@ -29,7 +31,7 @@ __all__ = [
 
 AUTHZ_POLICY_ATTRIBUTES_SEPARATOR = "^"
 EXTERNAL_KEY_SEPARATOR = ":"
-GENERIC_SCOPE_WILDCARD = "*"
+GLOBAL_SCOPE_WILDCARD = "*"
 NAMESPACED_KEY_PATTERN = rf"^.+{re.escape(AUTHZ_POLICY_ATTRIBUTES_SEPARATOR)}.+$"
 
 
@@ -179,6 +181,14 @@ class ScopeMeta(type):
         if cls is not ScopeData:
             return super().__call__(*args, **kwargs)
 
+        # When working with global scopes, we can't determine subclass with an external_key since
+        # a global scope it's not attached to a specific resource type. So we only use * as
+        # an external_key to mean generic scope which maps to base ScopeData class.
+        # The only remaining issue is that internally the namespace key used in policies will be
+        # The global scope namespace (global^*), so we need to handle that case here.
+        if kwargs.get("external_key") == GLOBAL_SCOPE_WILDCARD:
+            return super().__call__(*args, **kwargs)
+
         if "namespaced_key" in kwargs:
             scope_cls = cls.get_subclass_by_namespaced_key(kwargs["namespaced_key"])
             return super(ScopeMeta, scope_cls).__call__(*args, **kwargs)
@@ -196,7 +206,7 @@ class ScopeMeta(type):
         Extracts the namespace prefix (before '^') and returns the registered subclass.
 
         Args:
-            namespaced_key: The namespaced key (e.g., 'lib^lib:DemoX:CSPROB', 'sc^generic').
+            namespaced_key: The namespaced key (e.g., 'lib^lib:DemoX:CSPROB', 'global^generic').
 
         Returns:
             The ScopeData subclass for the namespace, or ScopeData if namespace not recognized.
@@ -204,7 +214,7 @@ class ScopeMeta(type):
         Examples:
             >>> ScopeMeta.get_subclass_by_namespaced_key('lib^lib:DemoX:CSPROB')
             <class 'ContentLibraryData'>
-            >>> ScopeMeta.get_subclass_by_namespaced_key('sc^generic')
+            >>> ScopeMeta.get_subclass_by_namespaced_key('global^generic')
             <class 'ScopeData'>
         """
         # TODO: Default separator, can't access directly from class so made it a constant
@@ -222,7 +232,7 @@ class ScopeMeta(type):
         the key format using the subclass's validate_external_key method.
 
         Args:
-            external_key: The external key (e.g., 'lib:DemoX:CSPROB', 'sc:generic').
+            external_key: The external key (e.g., 'lib:DemoX:CSPROB', 'global:generic').
 
         Returns:
             The ScopeData subclass corresponding to the namespace.
@@ -261,11 +271,11 @@ class ScopeMeta(type):
 
         Returns:
             dict[str, Type["ScopeData"]]: A dictionary of all namespace prefixes registered in the scope registry.
-                Each namespace corresponds to a ScopeData subclass (e.g., 'lib', 'sc').
+                Each namespace corresponds to a ScopeData subclass (e.g., 'lib', 'global').
 
         Examples:
             >>> ScopeMeta.get_all_namespaces()
-            {'sc': ScopeData, 'lib': ContentLibraryData, 'org': OrganizationData}
+            {'global': ScopeData, 'lib': ContentLibraryData, 'org': OrganizationData}
         """
         return mcs.scope_registry
 
@@ -291,17 +301,22 @@ class ScopeData(AuthZData, metaclass=ScopeMeta):
     and not tied to any specific scope type, holding attributes common to all scopes.
 
     Attributes:
-        NAMESPACE: 'sc' for generic scopes.
+        NAMESPACE: 'global' for generic scopes.
         external_key: The scope identifier without namespace (e.g., 'generic_scope').
-        namespaced_key: The scope identifier with namespace (e.g., 'sc^generic_scope').
+        namespaced_key: The scope identifier with namespace (e.g., 'global^generic_scope').
 
     Examples:
         >>> scope = ScopeData(external_key='generic_scope')
         >>> scope.namespaced_key
-        'sc^generic_scope'
+        'global^generic_scope'
     """
 
-    NAMESPACE: ClassVar[str] = "sc"
+    # The 'global' namespace is used for scopes that aren't tied to a specific resource type.
+    # This base class supports:
+    # 1. Global wildcard scopes (external_key='*') that apply across all resource types
+    # 2. Custom global scopes that don't map to specific domain objects (e.g., 'global:some_scope')
+    # Subclasses like ContentLibraryData ('lib') represent concrete resource types with their own namespaces.
+    NAMESPACE: ClassVar[str] = "global"
 
     @classmethod
     def validate_external_key(cls, _: str) -> bool:
@@ -319,6 +334,20 @@ class ScopeData(AuthZData, metaclass=ScopeMeta):
         """
         return True
 
+    @abstractmethod
+    def get_object(self) -> Any | None:
+        """Retrieve the underlying domain object that this scope represents.
+
+        This method fetches the actual Open edX object (e.g., ContentLibrary, Organization)
+        associated with this scope's external_key. Subclasses should implement this to return
+        their specific object types.
+
+        Returns:
+            Any | None: The domain object associated with this scope, or None if the object
+                does not exist or cannot be retrieved.
+        """
+        raise NotImplementedError("Subclasses must implement get_object method.")
+
     @abstractmethod
     def exists(self) -> bool:
         """Check if the scope exists.
@@ -366,6 +395,15 @@ class ContentLibraryData(ScopeData):
         """
         return self.external_key
 
+    @property
+    def library_key(self) -> LibraryLocatorV2:
+        """The LibraryLocatorV2 object for the content library.
+
+        Returns:
+            LibraryLocatorV2: The library locator object.
+        """
+        return LibraryLocatorV2.from_string(self.library_id)
+
     @classmethod
     def validate_external_key(cls, external_key: str) -> bool:
         """Validate the external_key format for ContentLibraryData.
@@ -382,18 +420,38 @@ class ContentLibraryData(ScopeData):
         except InvalidKeyError:
             return False
 
+    def get_object(self) -> ContentLibrary | None:
+        """Retrieve the ContentLibrary instance associated with this scope.
+
+        This method converts the library_id to a LibraryLocatorV2 key and queries the
+        database to fetch the corresponding ContentLibrary object.
+
+        Returns:
+            ContentLibrary | None: The ContentLibrary instance if found in the database,
+                or None if the library does not exist or has an invalid key format.
+
+        Examples:
+            >>> library_scope = ContentLibraryData(external_key='lib:DemoX:CSPROB')
+            >>> library_obj = library_scope.get_object() # ContentLibrary object
+        """
+        try:
+            library_obj = ContentLibrary.objects.get_by_key(self.library_key)
+            # Validate canonical key: get_by_key is case-insensitive, but we require exact match
+            # This ensures authorization uses canonical library IDs consistently
+            if library_obj.library_key != self.library_key:
+                raise ContentLibrary.DoesNotExist
+        except (InvalidKeyError, ContentLibrary.DoesNotExist):
+            return None
+
+        return library_obj
+
     def exists(self) -> bool:
         """Check if the content library exists.
 
         Returns:
             bool: True if the content library exists, False otherwise.
         """
-        try:
-            library_key = LibraryLocatorV2.from_string(self.library_id)
-            ContentLibrary.objects.get_by_key(library_key=library_key)
-            return True
-        except ContentLibrary.DoesNotExist:
-            return False
+        return self.get_object() is not None
 
     def __str__(self):
         """Human readable string representation of the content library."""
@@ -611,6 +669,30 @@ class PermissionData:
         """
         return self.action.external_key
 
+    def __eq__(self, other: "PermissionData") -> bool:
+        """Compare permissions based on their action identifier.
+
+        Two PermissionData instances are considered equal if they have the same action's
+        external_key and effect.
+
+        Args:
+            other: Another PermissionData instance or any object.
+
+        Returns:
+            bool: True if the actions match, False otherwise.
+
+        Example:
+            >>> perm1 = PermissionData(action=ActionData(external_key='view'), effect='allow')
+            >>> perm2 = PermissionData(action=ActionData(external_key='view'), effect='allow')
+            >>> perm1 == perm2  # True - same action and effect
+            True
+            >>> perm1 in [perm2]  # Uses __eq__
+            True
+        """
+        if self.action is None or other.action is None:
+            return False
+        return self.action.external_key == other.action.external_key and self.effect == other.effect
+
     def __str__(self):
         """Human readable string representation of the permission and its effect."""
         return f"{self.action} - {self.effect}"
