@@ -37,6 +37,7 @@ __all__ = [
     "get_subject_role_assignments_for_role_in_scope",
     "get_all_subject_role_assignments_in_scope",
     "get_subject_role_assignments",
+    "get_scopes_for_subject_and_permission",
 ]
 
 # TODO: these are the concerns we still have to address:
@@ -361,15 +362,42 @@ def get_all_subject_role_assignments_in_scope(
     return list(role_assignments_per_subject.values())
 
 
-def get_subjects_for_role(role: RoleData) -> list[SubjectData]:
-    """Get all the subjects assigned to a specific role.
+def get_subjects_for_role_in_scope(role: RoleData, scope: ScopeData) -> list[SubjectData]:
+    """Get all the subjects assigned to a specific role in a specific scope.
 
     Args:
         role (RoleData): The role to filter subjects.
+        scope (ScopeData): The scope to filter subjects.
 
     Returns:
-        list[SubjectData]: A list of subjects assigned to the specified role.
+        list[SubjectData]: A list of subjects assigned to the specified role in the specified scope.
     """
     enforcer = AuthzEnforcer.get_enforcer()
     policies = enforcer.get_filtered_grouping_policy(GroupingPolicyIndex.ROLE.value, role.namespaced_key)
-    return [SubjectData(namespaced_key=policy[GroupingPolicyIndex.SUBJECT.value]) for policy in policies]
+    return [
+        SubjectData(namespaced_key=policy[GroupingPolicyIndex.SUBJECT.value])
+        for policy in policies
+        if policy[GroupingPolicyIndex.SCOPE.value] == scope.namespaced_key
+    ]
+
+
+def get_scopes_for_subject_and_permission(
+    subject: SubjectData,
+    permission: PermissionData,
+) -> list[ScopeData]:
+    """Get all scopes where a specific subject has been assigned a specific permission via roles.
+
+    Args:
+        permission (PermissionData): The permission to filter scopes.
+        subject (SubjectData): The subject to filter scopes.
+
+    Returns:
+        list[ScopeData]: A list of scopes where the subject is assigned the specified permission.
+    """
+    roles_for_subject = get_subject_role_assignments(subject)
+    scopes = []
+    for role_assignment in roles_for_subject:
+        for role in role_assignment.roles:
+            if permission in role.permissions and role_assignment.scope not in scopes:
+                scopes.append(role_assignment.scope)
+    return scopes
