@@ -1,7 +1,10 @@
 """Test data for the authorization API."""
 
+from unittest.mock import Mock, patch
+
 from ddt import data, ddt, unpack
 from django.test import TestCase
+from opaque_keys.edx.locator import LibraryLocatorV2
 
 from openedx_authz.api.data import (
     ActionData,
@@ -14,6 +17,7 @@ from openedx_authz.api.data import (
     SubjectData,
     UserData,
 )
+from openedx_authz.constants import permissions, roles
 
 
 @ddt
@@ -151,7 +155,7 @@ class TestPolymorphicData(TestCase):
         """Test that ScopeData can be instantiated with namespaced_key.
 
         Expected Result:
-            - ScopeData(namespaced_key='sc^generic') creates ScopeData instance
+            - ScopeData(namespaced_key='global^generic') creates ScopeData instance
         """
         namespaced_key = f"{ScopeData.NAMESPACE}{ScopeData.SEPARATOR}generic"
 
@@ -218,17 +222,17 @@ class TestScopeMetaClass(TestCase):
         """Test that ScopeData and its subclasses are registered correctly.
 
         Expected Result:
-            - 'sc' namespace maps to ScopeData class
+            - 'global' namespace maps to ScopeData class
             - 'lib' namespace maps to ContentLibraryData class
         """
-        self.assertIn("sc", ScopeData.scope_registry)
-        self.assertIs(ScopeData.scope_registry["sc"], ScopeData)
+        self.assertIn("global", ScopeData.scope_registry)
+        self.assertIs(ScopeData.scope_registry["global"], ScopeData)
         self.assertIn("lib", ScopeData.scope_registry)
         self.assertIs(ScopeData.scope_registry["lib"], ContentLibraryData)
 
     @data(
         ("lib^lib:DemoX:CSPROB", ContentLibraryData),
-        ("sc^generic_scope", ScopeData),
+        ("global^generic_scope", ScopeData),
     )
     @unpack
     def test_dynamic_instantiation_via_namespaced_key(self, namespaced_key, expected_class):
@@ -236,7 +240,7 @@ class TestScopeMetaClass(TestCase):
 
         Expected Result:
             - ScopeData(namespaced_key='lib^...') returns ContentLibraryData instance
-            - ScopeData(namespaced_key='sc^...') returns ScopeData instance
+            - ScopeData(namespaced_key='global^...') returns ScopeData instance
         """
         instance = ScopeData(namespaced_key=namespaced_key)
 
@@ -245,7 +249,7 @@ class TestScopeMetaClass(TestCase):
 
     @data(
         ("lib^lib:DemoX:CSPROB", ContentLibraryData),
-        ("sc^generic", ScopeData),
+        ("global^generic", ScopeData),
         ("unknown^something", ScopeData),
     )
     @unpack
@@ -254,7 +258,7 @@ class TestScopeMetaClass(TestCase):
 
         Expected Result:
             - 'lib^...' returns ContentLibraryData
-            - 'sc^...' returns ScopeData
+            - 'global^...' returns ScopeData
             - 'unknown^...' returns ScopeData (fallback)
         """
         subclass = ScopeMeta.get_subclass_by_namespaced_key(namespaced_key)
@@ -264,7 +268,7 @@ class TestScopeMetaClass(TestCase):
     @data(
         ("lib:DemoX:CSPROB", ContentLibraryData),
         ("lib:edX:Demo", ContentLibraryData),
-        ("sc:generic_scope", ScopeData),
+        ("global:generic_scope", ScopeData),
     )
     @unpack
     def test_get_subclass_by_external_key(self, external_key, expected_class):
@@ -272,7 +276,7 @@ class TestScopeMetaClass(TestCase):
 
         Expected Result:
             - 'lib:...' returns ContentLibraryData
-            - 'sc:...' returns ScopeData
+            - 'global:...' returns ScopeData
         """
         subclass = ScopeMeta.get_subclass_by_external_key(external_key)
 
@@ -315,12 +319,12 @@ class TestScopeMetaClass(TestCase):
             - ScopeData(external_key='...') creates ScopeData instance
             - No dynamic subclass selection occurs
         """
-        scope = ScopeData(external_key="sc:generic_scope")
+        scope = ScopeData(external_key="global:generic_scope")
 
-        expected_namespaced = f"{ScopeData.NAMESPACE}{ScopeData.SEPARATOR}sc:generic_scope"
+        expected_namespaced = f"{ScopeData.NAMESPACE}{ScopeData.SEPARATOR}global:generic_scope"
 
         self.assertIsInstance(scope, ScopeData)
-        self.assertEqual(scope.external_key, "sc:generic_scope")
+        self.assertEqual(scope.external_key, "global:generic_scope")
         self.assertEqual(scope.namespaced_key, expected_namespaced)
 
     def test_empty_namespaced_key_raises_value_error(self):
@@ -341,6 +345,27 @@ class TestScopeMetaClass(TestCase):
         with self.assertRaises(ValueError):
             SubjectData(external_key="")
 
+    def test_scope_data_with_wildcard_external_key(self):
+        """Test that ScopeData instantiated with wildcard (*) returns base ScopeData.
+
+        When using the global scope wildcard '*', the metaclass should return a base
+        ScopeData instance rather than attempting subclass determination.
+
+        Expected Result:
+            - ScopeData(external_key='*') creates base ScopeData instance
+            - namespaced_key is 'global^*'
+            - No subclass determination occurs
+        """
+        scope = ScopeData(external_key="*")
+
+        expected_namespaced = f"{ScopeData.NAMESPACE}{ScopeData.SEPARATOR}*"
+
+        self.assertIsInstance(scope, ScopeData)
+        # Ensure it's exactly ScopeData, not a subclass
+        self.assertEqual(type(scope), ScopeData)
+        self.assertEqual(scope.external_key, "*")
+        self.assertEqual(scope.namespaced_key, expected_namespaced)
+
 
 @ddt
 class TestDataRepresentation(TestCase):
@@ -369,7 +394,7 @@ class TestDataRepresentation(TestCase):
     @data(
         ("read", "Read", "act^read"),
         ("write", "Write", "act^write"),
-        ("delete_library", "Delete Library", "act^delete_library"),
+        (permissions.DELETE_LIBRARY.identifier, "Delete Library", "act^delete_library"),
         ("edit_content", "Edit Content", "act^edit_content"),
     )
     @unpack
@@ -410,7 +435,7 @@ class TestDataRepresentation(TestCase):
 
     @data(
         ("instructor", "Instructor", "role^instructor"),
-        ("library_admin", "Library Admin", "role^library_admin"),
+        (roles.LIBRARY_ADMIN.external_key, "Library Admin", "role^library_admin"),
         ("course_staff", "Course Staff", "role^course_staff"),
     )
     @unpack
@@ -451,7 +476,7 @@ class TestDataRepresentation(TestCase):
         ("read", "allow", "Read - allow", "act^read => allow"),
         ("write", "deny", "Write - deny", "act^write => deny"),
         (
-            "delete_library",
+            permissions.DELETE_LIBRARY.identifier,
             "allow",
             "Delete Library - allow",
             "act^delete_library => allow",
@@ -482,7 +507,7 @@ class TestDataRepresentation(TestCase):
         """
         user = UserData(external_key="john_doe")
         role1 = RoleData(external_key="instructor")
-        role2 = RoleData(external_key="library_admin")
+        role2 = RoleData(external_key=roles.LIBRARY_ADMIN.external_key)
         scope = ContentLibraryData(external_key="lib:DemoX:CSPROB")
         assignment = RoleAssignmentData(subject=user, roles=[role1, role2], scope=scope)
 
@@ -499,7 +524,7 @@ class TestDataRepresentation(TestCase):
         """
         user = UserData(external_key="john_doe")
         role1 = RoleData(external_key="instructor")
-        role2 = RoleData(external_key="library_admin")
+        role2 = RoleData(external_key=roles.LIBRARY_ADMIN.external_key)
         scope = ContentLibraryData(external_key="lib:DemoX:CSPROB")
         assignment = RoleAssignmentData(subject=user, roles=[role1, role2], scope=scope)
 
@@ -507,3 +532,111 @@ class TestDataRepresentation(TestCase):
 
         expected_repr = "user^john_doe => [role^instructor, role^library_admin] @ lib^lib:DemoX:CSPROB"
         self.assertEqual(actual_repr, expected_repr)
+
+
+@ddt
+class TestContentLibraryData(TestCase):
+    """Test the ContentLibraryData class."""
+
+    @patch("openedx_authz.api.data.ContentLibrary")
+    def test_get_object_success(self, mock_content_library_model):
+        """Test get_object returns ContentLibrary when it exists with valid key.
+
+        Expected Result:
+            - Returns the ContentLibrary object when library exists
+            - Library key matches exactly (canonical validation passes)
+        """
+        library_id = "lib:DemoX:CSPROB"
+        library_scope = ContentLibraryData(external_key=library_id)
+        mock_library_obj = Mock()
+        mock_library_obj.library_key = library_scope.library_key
+        mock_content_library_model.objects.get_by_key.return_value = mock_library_obj
+
+        result = library_scope.get_object()
+
+        self.assertEqual(result, mock_library_obj)
+        mock_content_library_model.objects.get_by_key.assert_called_once_with(library_scope.library_key)
+
+    @patch("openedx_authz.api.data.ContentLibrary")
+    def test_get_object_does_not_exist(self, mock_content_library_model):
+        """Test get_object returns None when library does not exist.
+
+        Expected Result:
+            - Returns None when ContentLibrary.DoesNotExist is raised
+        """
+        library_id = "lib:DemoX:NonExistent"
+        library_scope = ContentLibraryData(external_key=library_id)
+        mock_content_library_model.DoesNotExist = Exception
+        mock_content_library_model.objects.get_by_key.side_effect = mock_content_library_model.DoesNotExist
+
+        result = library_scope.get_object()
+
+        self.assertIsNone(result)
+
+    @patch("openedx_authz.api.data.ContentLibrary")
+    def test_get_object_invalid_key_format(self, mock_content_library_model):
+        """Test get_object returns None when library_id has invalid format.
+
+        Expected Result:
+            - Returns None when InvalidKeyError is raised during key parsing
+        """
+        mock_content_library_model.DoesNotExist = Exception
+        library_scope = ContentLibraryData(external_key="invalid-library-format")
+
+        result = library_scope.get_object()
+
+        self.assertIsNone(result)
+        mock_content_library_model.objects.get_by_key.assert_not_called()
+
+    @patch("openedx_authz.api.data.ContentLibrary")
+    def test_get_object_non_canonical_key(self, mock_content_library_model):
+        """Test get_object returns None when library key is not canonical.
+
+        This test verifies the canonical key validation: get_by_key is case-insensitive,
+        but we require exact match to ensure authorization uses canonical library IDs.
+
+        Expected Result:
+            - Returns None when retrieved library's key doesn't match exactly
+            - Simulates case where user provides 'lib:demox:csprob' but canonical is 'lib:DemoX:CSPROB'
+        """
+        library_id = "lib:DemoX:CSPROB"
+        library_key = LibraryLocatorV2.from_string(library_id)
+        # Convert to lowercase to simulate case-insensitive comparison
+        library_scope = ContentLibraryData(external_key=library_id.lower())
+        mock_content_library_model.objects.get_by_key.return_value = Mock(library_key=library_key)
+        mock_content_library_model.DoesNotExist = Exception
+
+        result = library_scope.get_object()
+
+        self.assertIsNone(result)
+
+    @patch("openedx_authz.api.data.ContentLibrary")
+    def test_exists_returns_true_when_library_exists(self, mock_content_library_model):
+        """Test exists() returns True when get_object() returns a library.
+
+        Expected Result:
+            - exists() returns True when library object is found
+        """
+        library_id = "lib:DemoX:CSPROB"
+        library_scope = ContentLibraryData(external_key=library_id)
+        mock_content_library_model.objects.get_by_key.return_value = Mock(library_key=library_scope.library_key)
+
+        result = library_scope.exists()
+
+        self.assertTrue(result)
+
+    @patch("openedx_authz.api.data.ContentLibrary")
+    def test_exists_returns_false_when_library_does_not_exist(self, mock_content_library_model):
+        """Test exists() returns False when get_object() returns None.
+
+        Expected Result:
+            - exists() returns False when library is not found
+        """
+        library_id = "lib:DemoX:NonExistent"
+        library_scope = ContentLibraryData(external_key=library_id)
+        mock_content_library_model.DoesNotExist = Exception
+        mock_content_library_model.objects.get_by_key.side_effect = mock_content_library_model.DoesNotExist
+
+        result = library_scope.exists()
+
+        self.assertFalse(result)
