@@ -16,6 +16,7 @@ from rest_framework.test import APIClient
 
 from openedx_authz import api
 from openedx_authz.api.users import assign_role_to_user_in_scope
+from openedx_authz.constants import permissions, roles
 from openedx_authz.rest_api.data import RoleOperationError, RoleOperationStatus
 from openedx_authz.rest_api.v1.permissions import DynamicScopePermission
 from openedx_authz.tests.api.test_roles import BaseRolesTestCase
@@ -38,10 +39,7 @@ class ViewTestMixin(BaseRolesTestCase):
     """Mixin providing common test utilities for view tests."""
 
     @classmethod
-    def _assign_roles_to_users(
-        cls,
-        assignments: list[dict] | None = None,
-    ):
+    def _assign_roles_to_users(cls, assignments: list[dict] | None = None):
         """Helper method to assign roles to multiple users.
 
         This method can be used to assign a role to a single user or multiple users
@@ -68,58 +66,58 @@ class ViewTestMixin(BaseRolesTestCase):
             # Assign roles to admin users
             {
                 "subject_name": "admin_1",
-                "role_name": "library_admin",
+                "role_name": roles.LIBRARY_ADMIN.external_key,
                 "scope_name": "lib:Org1:LIB1",
             },
             {
                 "subject_name": "admin_2",
-                "role_name": "library_user",
+                "role_name": roles.LIBRARY_USER.external_key,
                 "scope_name": "lib:Org2:LIB2",
             },
             {
                 "subject_name": "admin_3",
-                "role_name": "library_admin",
+                "role_name": roles.LIBRARY_ADMIN.external_key,
                 "scope_name": "lib:Org3:LIB3",
             },
             # Assign roles to regular users
             {
                 "subject_name": "regular_1",
-                "role_name": "library_user",
+                "role_name": roles.LIBRARY_USER.external_key,
                 "scope_name": "lib:Org1:LIB1",
             },
             {
                 "subject_name": "regular_2",
-                "role_name": "library_user",
+                "role_name": roles.LIBRARY_USER.external_key,
                 "scope_name": "lib:Org1:LIB1",
             },
             {
                 "subject_name": "regular_3",
-                "role_name": "library_user",
+                "role_name": roles.LIBRARY_USER.external_key,
                 "scope_name": "lib:Org2:LIB2",
             },
             {
                 "subject_name": "regular_4",
-                "role_name": "library_user",
+                "role_name": roles.LIBRARY_USER.external_key,
                 "scope_name": "lib:Org2:LIB2",
             },
             {
                 "subject_name": "regular_5",
-                "role_name": "library_admin",
+                "role_name": roles.LIBRARY_ADMIN.external_key,
                 "scope_name": "lib:Org3:LIB3",
             },
             {
                 "subject_name": "regular_6",
-                "role_name": "library_author",
+                "role_name": roles.LIBRARY_AUTHOR.external_key,
                 "scope_name": "lib:Org3:LIB3",
             },
             {
                 "subject_name": "regular_7",
-                "role_name": "library_collaborator",
+                "role_name": "library_contributor",
                 "scope_name": "lib:Org3:LIB3",
             },
             {
                 "subject_name": "regular_8",
-                "role_name": "library_user",
+                "role_name": roles.LIBRARY_USER.external_key,
                 "scope_name": "lib:Org3:LIB3",
             },
         ]
@@ -164,16 +162,16 @@ class TestPermissionValidationMeView(ViewTestMixin):
 
     @data(
         # Single permission - allowed
-        ([{"action": "view_library", "scope": "lib:Org1:LIB1"}], [True]),
+        ([{"action": permissions.VIEW_LIBRARY.identifier, "scope": "lib:Org1:LIB1"}], [True]),
         # Single permission - denied (scope not assigned to user)
-        ([{"action": "view_library", "scope": "lib:Org2:LIB2"}], [False]),
-        # # Single permission - denied (action not assigned to user)
+        ([{"action": permissions.VIEW_LIBRARY.identifier, "scope": "lib:Org2:LIB2"}], [False]),
+        # Single permission - denied (action not assigned to user)
         ([{"action": "edit_library", "scope": "lib:Org1:LIB1"}], [False]),
-        # # Multiple permissions - mixed results
+        # Multiple permissions - mixed results
         (
             [
-                {"action": "view_library", "scope": "lib:Org1:LIB1"},
-                {"action": "view_library", "scope": "lib:Org2:LIB2"},
+                {"action": permissions.VIEW_LIBRARY.identifier, "scope": "lib:Org1:LIB1"},
+                {"action": permissions.VIEW_LIBRARY.identifier, "scope": "lib:Org2:LIB2"},
                 {"action": "edit_library", "scope": "lib:Org1:LIB1"},
             ],
             [True, False, False],
@@ -304,23 +302,23 @@ class TestRoleUserAPIView(ViewTestMixin):
         ({"search": "@example.com"}, 3),
         ({"search": "nonexistent@example.com"}, 0),
         # Search by single role
-        ({"roles": "library_admin"}, 1),
-        ({"roles": "library_author"}, 0),
-        ({"roles": "library_user"}, 2),
+        ({"roles": roles.LIBRARY_ADMIN.external_key}, 1),
+        ({"roles": roles.LIBRARY_AUTHOR.external_key}, 0),
+        ({"roles": roles.LIBRARY_USER.external_key}, 2),
         # Search by multiple roles
         ({"roles": "library_admin,library_author"}, 1),
         ({"roles": "library_author,library_user"}, 2),
         ({"roles": "library_user,library_admin"}, 3),
         ({"roles": "library_admin,library_author,library_user"}, 3),
         # Search by role and username
-        ({"search": "admin_1", "roles": "library_admin"}, 1),
-        ({"search": "regular_1", "roles": "library_user"}, 1),
-        ({"search": "regular_1", "roles": "library_admin"}, 0),
+        ({"search": "admin_1", "roles": roles.LIBRARY_ADMIN.external_key}, 1),
+        ({"search": "regular_1", "roles": roles.LIBRARY_USER.external_key}, 1),
+        ({"search": "regular_1", "roles": roles.LIBRARY_ADMIN.external_key}, 0),
         # Search by role and email
-        ({"search": "admin_1@example.com", "roles": "library_admin"}, 1),
-        ({"search": "@example.com", "roles": "library_admin"}, 1),
-        ({"search": "@example.com", "roles": "library_user"}, 2),
-        ({"search": "regular_1@example.com", "roles": "library_admin"}, 0),
+        ({"search": "admin_1@example.com", "roles": roles.LIBRARY_ADMIN.external_key}, 1),
+        ({"search": "@example.com", "roles": roles.LIBRARY_ADMIN.external_key}, 1),
+        ({"search": "@example.com", "roles": roles.LIBRARY_USER.external_key}, 2),
+        ({"search": "regular_1@example.com", "roles": roles.LIBRARY_ADMIN.external_key}, 0),
     )
     @unpack
     def test_get_users_by_scope_success(self, query_params: dict, expected_count: int):
@@ -434,7 +432,7 @@ class TestRoleUserAPIView(ViewTestMixin):
             - Returns 207 MULTI-STATUS status
             - Returns appropriate completed and error counts
         """
-        role = "library_admin"
+        role = roles.LIBRARY_ADMIN.external_key
         request_data = {"role": role, "scope": "lib:Org1:LIB3", "users": users}
 
         with patch.object(api.ContentLibraryData, "exists", return_value=True):
@@ -457,7 +455,7 @@ class TestRoleUserAPIView(ViewTestMixin):
     @unpack
     def test_add_users_to_role_already_has_role(self, users: list[str], expected_completed: int, expected_errors: int):
         """Test adding users to a role that already has the role."""
-        role = "library_user"
+        role = roles.LIBRARY_USER.external_key
         scope = "lib:Org2:LIB2"
         request_data = {"role": role, "scope": scope, "users": users}
 
@@ -472,7 +470,7 @@ class TestRoleUserAPIView(ViewTestMixin):
     def test_add_users_to_role_exception_handling(self, mock_assign_role_to_user_in_scope):
         """Test adding users to a role with exception handling."""
         request_data = {
-            "role": "library_admin",
+            "role": roles.LIBRARY_ADMIN.external_key,
             "scope": "lib:Org1:LIB1",
             "users": ["regular_1"],
         }
@@ -492,15 +490,15 @@ class TestRoleUserAPIView(ViewTestMixin):
 
     @data(
         {},
-        {"role": "library_admin"},
+        {"role": roles.LIBRARY_ADMIN.external_key},
         {"scope": "lib:Org1:LIB1"},
         {"users": ["admin_1"]},
-        {"role": "library_admin", "scope": "lib:Org1:LIB1"},
+        {"role": roles.LIBRARY_ADMIN.external_key, "scope": "lib:Org1:LIB1"},
         {"scope": "lib:Org1:LIB1", "users": ["admin_1"]},
-        {"users": ["admin_1", "regular_1"], "role": "library_admin"},
-        {"role": "library_admin", "scope": "lib:Org1:LIB1", "users": []},
+        {"users": ["admin_1", "regular_1"], "role": roles.LIBRARY_ADMIN.external_key},
+        {"role": roles.LIBRARY_ADMIN.external_key, "scope": "lib:Org1:LIB1", "users": []},
         {"role": "", "scope": "lib:Org1:LIB1", "users": ["admin_1"]},
-        {"role": "library_admin", "scope": "", "users": ["admin_1"]},
+        {"role": roles.LIBRARY_ADMIN.external_key, "scope": "", "users": ["admin_1"]},
     )
     def test_add_users_to_role_invalid_data(self, request_data: dict):
         """Test adding users with invalid request data.
@@ -531,7 +529,7 @@ class TestRoleUserAPIView(ViewTestMixin):
             - Returns appropriate status code based on permissions
         """
         request_data = {
-            "role": "library_admin",
+            "role": roles.LIBRARY_ADMIN.external_key,
             "scope": "lib:Org3:LIB3",
             "users": ["regular_2"],
         }
@@ -586,7 +584,7 @@ class TestRoleUserAPIView(ViewTestMixin):
             - Returns appropriate completed and error counts
         """
         query_params = {
-            "role": "library_user",
+            "role": roles.LIBRARY_USER.external_key,
             "scope": "lib:Org2:LIB2",
             "users": ",".join(users),
         }
@@ -602,7 +600,7 @@ class TestRoleUserAPIView(ViewTestMixin):
     def test_remove_users_from_role_exception_handling(self, mock_unassign_role_from_user):
         """Test removing users from a role with exception handling."""
         query_params = {
-            "role": "library_admin",
+            "role": roles.LIBRARY_ADMIN.external_key,
             "scope": "lib:Org1:LIB1",
             "users": "regular_1,regular_2,regular_3",
         }
@@ -631,15 +629,15 @@ class TestRoleUserAPIView(ViewTestMixin):
 
     @data(
         {},
-        {"role": "library_admin"},
+        {"role": roles.LIBRARY_ADMIN.external_key},
         {"scope": "lib:Org1:LIB1"},
         {"users": "admin_1"},
-        {"role": "library_admin", "scope": "lib:Org1:LIB1"},
+        {"role": roles.LIBRARY_ADMIN.external_key, "scope": "lib:Org1:LIB1"},
         {"scope": "lib:Org1:LIB1", "users": "admin_1"},
-        {"users": "admin_1,regular_1", "role": "library_admin"},
-        {"role": "library_admin", "scope": "lib:Org1:LIB1", "users": ""},
+        {"users": "admin_1,regular_1", "role": roles.LIBRARY_ADMIN.external_key},
+        {"role": roles.LIBRARY_ADMIN.external_key, "scope": "lib:Org1:LIB1", "users": ""},
         {"role": "", "scope": "lib:Org1:LIB1", "users": "admin_1"},
-        {"role": "library_admin", "scope": "", "users": "admin_1"},
+        {"role": roles.LIBRARY_ADMIN.external_key, "scope": "", "users": "admin_1"},
     )
     def test_remove_users_from_role_invalid_params(self, query_params: dict):
         """Test removing users with invalid query parameters.
@@ -669,7 +667,7 @@ class TestRoleUserAPIView(ViewTestMixin):
             - Returns appropriate status code based on permissions
         """
         query_params = {
-            "role": "library_admin",
+            "role": roles.LIBRARY_ADMIN.external_key,
             "scope": "lib:Org3:LIB3",
             "users": "user1,user2",
         }
@@ -792,9 +790,9 @@ class TestRoleListView(ViewTestMixin):
         # Library Admin user
         ("regular_5", status.HTTP_200_OK),
         # Library Author user
-        # ("regular_6", status.HTTP_200_OK),  # TODO: uncomment this when we have the explicit permissions
-        # Library Collaborator user
-        # ("regular_7", status.HTTP_200_OK),  # TODO: uncomment this when we have the explicit permissions
+        ("regular_6", status.HTTP_200_OK),
+        # Library Contributor user
+        ("regular_7", status.HTTP_200_OK),
         # Library User user
         ("regular_8", status.HTTP_200_OK),
         # Regular user without permission
